==> ukui-sidebar_1.1.1.orig.tar.gz: ukui-sidebar/src/plugins/feedback/Resource/feedback_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>feedback</name>
    <message>
        <location filename="../feedback.ui" line="38"/>
        <location filename="../feedback.ui" line="58"/>
        <source>feedback</source>
        <translation type="unfinished">feedback</translation>
    </message>
    <message>
        <source>问题反馈</source>
        <translation type="obsolete">feedback</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="75"/>
        <source>系统问题</source>
        <translation type="unfinished">system issue</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="80"/>
        <source>意见建议</source>
        <translation type="unfinished">suggestions</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="85"/>
        <source>商务合作</source>
        <translation type="unfinished">Business Cooperation</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="90"/>
        <source>其他</source>
        <translation type="unfinished">other</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="109"/>
        <source>问题描述</source>
        <translation type="unfinished">Problem Description</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="140"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;dfddfd&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="143"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;uyghjg&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="153"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="176"/>
        <source>邮箱</source>
        <translation type="unfinished">Email</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="193"/>
        <location filename="../feedback.ui" line="210"/>
        <source>*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="244"/>
        <source>上传附件</source>
        <translation type="unfinished">Uploadfile</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="279"/>
        <source>浏览...</source>
        <translation type="unfinished">Browse</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="307"/>
        <source>同意获取我的</source>
        <translation type="unfinished">Agreegetmy</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="338"/>
        <source>提交</source>
        <translation type="unfinished">Submit</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="367"/>
        <source>系统信息</source>
        <translation type="unfinished">systeminfo</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="385"/>
        <source>问题类型</source>
        <translation type="unfinished">Question</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="505"/>
        <source>syslog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="516"/>
        <source>apport.log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="528"/>
        <source>dpkg.log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="550"/>
        <source>日志文件</source>
        <translation type="unfinished">Logfile</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="567"/>
        <source>限200字</source>
        <translation type="unfinished">200 words</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="583"/>
        <source>文件大小超过了3MB或文件格式不支持</source>
        <translation type="unfinished">File size exceeds 3MB or file format is not supported</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="48"/>
        <source>用户反馈</source>
        <translation type="unfinished">feedback</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="80"/>
        <source>请输入内容</source>
        <translation type="unfinished">Please enter content</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="81"/>
        <source>文件大小不能超过3MB</source>
        <translation type="unfinished">File size cannot exceed 3MB</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="92"/>
        <source>select image</source>
        <translation type="unfinished">select image</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="624"/>
        <source>删除</source>
        <translation type="unfinished">delete</translation>
    </message>
</context>
<context>
    <name>submit_fail</name>
    <message>
        <location filename="../submit_fail.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../submit_fail.ui" line="33"/>
        <source>问题提交失败！</source>
        <translation type="unfinished">submit failed!</translation>
    </message>
    <message>
        <location filename="../submit_fail.ui" line="49"/>
        <source>退出</source>
        <translation type="unfinished">drop out</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="10"/>
        <source>提交失败</source>
        <translation type="unfinished">Submission Failed</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="19"/>
        <source>远程服务器拒绝连接</source>
        <translation type="unfinished">The remote server refused the connection</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="22"/>
        <source>服务器关闭</source>
        <translation type="unfinished">Server down</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="25"/>
        <source>找不到远程主机名（无效的主机名）</source>
        <translation type="unfinished">Cannot find remote host name</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="28"/>
        <source>与远程服务器的连接超时</source>
        <translation type="unfinished">Connection with remote server timed out</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="31"/>
        <source>未知错误</source>
        <translation type="unfinished">unknown mistake</translation>
    </message>
</context>
<context>
    <name>submit_success</name>
    <message>
        <location filename="../submit_success.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../submit_success.ui" line="33"/>
        <source>问题提交成功！</source>
        <translation type="unfinished">submit successfully!</translation>
    </message>
    <message>
        <location filename="../submit_success.ui" line="49"/>
        <source>继续反馈问题</source>
        <translation type="unfinished">Continue feedback</translation>
    </message>
    <message>
        <location filename="../submit_success.ui" line="65"/>
        <source>退出</source>
        <translation type="unfinished">drop out</translation>
    </message>
    <message>
        <location filename="../submit_success.cpp" line="11"/>
        <source>提交成功 </source>
        <translation type="unfinished">Submitted successfully</translation>
    </message>
</context>
</TS>

==> ukui-sidebar_1.1.2.orig.tar.gz: ukui-sidebar/src/plugins/feedback/Resource/feedback_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>QObject</name>
    <message>
        <location filename="../feedback_plugin.h" line="39"/>
        <location filename="../feedback_plugin.h" line="49"/>
        <location filename="../feedback_plugin.h" line="52"/>
        <source>用户反馈</source>
        <translatorcomment>feedback</translatorcomment>
        <translation type="unfinished">feedback</translation>
    </message>
    <message>
        <location filename="../feedback_plugin.h" line="41"/>
        <source>用户反馈问题的插件</source>
        <translatorcomment>feedback issue plugin</translatorcomment>
        <translation type="unfinished">feedback issue plugin</translation>
    </message>
</context>
<context>
    <name>feedback</name>
    <message>
        <location filename="../feedback.ui" line="38"/>
        <source>feedback</source>
        <translatorcomment>feedback</translatorcomment>
        <translation type="unfinished">feedback</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="58"/>
        <source>问题反馈</source>
        <translatorcomment>feedback</translatorcomment>
        <translation type="unfinished">feedback</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="75"/>
        <source>系统问题</source>
        <translatorcomment>system issue</translatorcomment>
        <translation type="unfinished">system issue</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="80"/>
        <source>意见建议</source>
        <translatorcomment>suggestions</translatorcomment>
        <translation>suggestions</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="85"/>
        <source>商务合作</source>
        <translatorcomment>Business Cooperation</translatorcomment>
        <translation type="unfinished">Business Cooperation</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="90"/>
        <source>其他</source>
        <translatorcomment>other</translatorcomment>
        <translation type="unfinished">other</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="109"/>
        <source>问题描述</source>
        <translatorcomment>Problem</translatorcomment>
        <translation type="unfinished">Problem</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="140"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;dfddfd&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="143"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;uyghjg&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="153"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="176"/>
        <source>邮箱</source>
        <translatorcomment>Email</translatorcomment>
        <translation type="unfinished">Email</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="193"/>
        <location filename="../feedback.ui" line="210"/>
        <source>*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="244"/>
        <source>上传附件</source>
        <translatorcomment>Upload</translatorcomment>
        <translation type="unfinished">Upload</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="279"/>
        <source>浏览...</source>
        <translatorcomment>Browse</translatorcomment>
        <translation type="unfinished">Browse</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="307"/>
        <source>同意获取我的</source>
        <translatorcomment>Agreegetmy</translatorcomment>
        <translation type="unfinished">Agreegetmy</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="338"/>
        <source>提交</source>
        <translatorcomment>Submit</translatorcomment>
        <translation type="unfinished">Submit</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="367"/>
        <source>系统信息</source>
        <translatorcomment>osinfo</translatorcomment>
        <translation type="unfinished">osinfo</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="385"/>
        <source>问题类型</source>
        <translatorcomment>Question</translatorcomment>
        <translation type="unfinished">Question</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="505"/>
        <source>syslog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="516"/>
        <source>apport.log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="528"/>
        <source>dpkg.log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="550"/>
        <source>日志文件</source>
        <translatorcomment>Logfile</translatorcomment>
        <translation type="unfinished">Logfile</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="567"/>
        <source>限200字</source>
        <translatorcomment>200words</translatorcomment>
        <translation type="unfinished">200words</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="583"/>
        <source>文件大小超过了3MB或文件格式不支持</source>
        <translatorcomment>File size exceeds 3MB or file format is not supported</translatorcomment>
        <translation type="unfinished">File size exceeds 3MB or file format is not supported</translation>
    </message>
    <message>
        <location filename="../feedback.ui" line="602"/>
        <source>请输入正确的邮箱格式</source>
        <translatorcomment>Please enter the correct email format</translatorcomment>
        <translation type="unfinished">Please enter the correct email format</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="66"/>
        <source>用户反馈</source>
        <translatorcomment>feedback</translatorcomment>
        <translation type="unfinished">feedback</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="90"/>
        <source>请输入内容</source>
        <translatorcomment>Please enter content</translatorcomment>
        <translation type="unfinished">Please enter content</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="91"/>
        <source>文件大小不能超过3MB</source>
        <translatorcomment>File size cannot exceed 10MB</translatorcomment>
        <translation type="unfinished">File size cannot exceed 10MB</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="123"/>
        <source>select image</source>
        <translatorcomment>select image</translatorcomment>
        <translation type="unfinished">select image</translation>
    </message>
    <message>
        <location filename="../feedback.cpp" line="717"/>
        <source>删除</source>
        <translatorcomment>delete</translatorcomment>
        <translation type="unfinished">delete</translation>
    </message>
</context>
<context>
    <name>submit_fail</name>
    <message>
        <location filename="../submit_fail.ui" line="14"/>
        <source>Dialog</source>
        <translatorcomment>Dialog</translatorcomment>
        <translation type="unfinished">Dialog</translation>
    </message>
    <message>
        <location filename="../submit_fail.ui" line="33"/>
        <source>问题提交失败！</source>
        <translatorcomment>submit failed!</translatorcomment>
        <translation type="unfinished">submit failed!</translation>
    </message>
    <message>
        <location filename="../submit_fail.ui" line="49"/>
        <source>退出             </source>
        <translatorcomment>Quit</translatorcomment>
        <translation type="unfinished">Quit</translation>
    </message>
    <message>
        <source>退出</source>
        <translation type="obsolete">drop out</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="27"/>
        <source>提交失败</source>
        <translatorcomment>Submission Failed</translatorcomment>
        <translation type="unfinished">Submission Failed</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="38"/>
        <source>远程服务器拒绝连接</source>
        <translatorcomment>The remote server refused the connection</translatorcomment>
        <translation type="unfinished">The remote server refused the connection</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="41"/>
        <source>服务器关闭</source>
        <translatorcomment>Server down</translatorcomment>
        <translation type="unfinished">Server down</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="44"/>
        <source>找不到远程主机名（无效的主机名）</source>
        <translatorcomment>Cannot find remote host name</translatorcomment>
        <translation type="unfinished">Cannot find remote host name</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="47"/>
        <source>与远程服务器的连接超时</source>
        <translatorcomment>Connection with remote server timed out</translatorcomment>
        <translation type="unfinished">Connection with remote server timed out</translation>
    </message>
    <message>
        <location filename="../submit_fail.cpp" line="50"/>
        <source>未知错误</source>
        <translatorcomment>unknown mistake</translatorcomment>
        <translation type="unfinished">unknown mistake</translation>
    </message>
</context>
<context>
    <name>submit_success</name>
    <message>
        <location filename="../submit_success.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../submit_success.ui" line="33"/>
        <source>问题提交成功！</source>
        <translatorcomment>submit successfully!</translatorcomment>
        <translation type="unfinished">submit successfully!</translation>
    </message>
    <message>
        <location filename="../submit_success.ui" line="49"/>
        <source>继续反馈问题     </source>
        <translatorcomment>Continue feedback</translatorcomment>
        <translation type="unfinished">Continue feedback</translation>
    </message>
    <message>
        <location filename="../submit_success.ui" line="65"/>
        <source>退出       </source>
        <translatorcomment>Quit</translatorcomment>
        <translation type="unfinished">Quit</translation>
    </message>
    <message>
        <source>继续反馈问题</source>
        <translation type="obsolete">Continue feedback</translation>
    </message>
    <message>
        <source>退出</source>
        <translation type="obsolete">drop out</translation>
    </message>
    <message>
        <location filename="../submit_success.cpp" line="28"/>
        <source>提交成功 </source>
        <translatorcomment>Submitted successfully</translatorcomment>
        <translation type="unfinished">Submitted successfully</translation>
    </message>
</context>
</TS>
